@@ -1,4 +1,10 @@
 package Tapper::Installer::Precondition::Image;
+BEGIN {
+  $Tapper::Installer::Precondition::Image::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Installer::Precondition::Image::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
@@ -12,46 +18,16 @@ has images => ( isa => 'ArrayRef',
               );
 
 
-=head1 NAME
 
-Tapper::Installer::Precondition::Package - Install a package to a given location
-
-=head1 SYNOPSIS
-
- use Tapper::Installer::Precondition::Image;
-
-=head1 FUNCTIONS
-
-=cut
-
-=head2 get_partition_number
-
-Get the partition part of grub notation of a given device file eg. /dev/hda1.
-
-@param string - partition number
-
-@return int - grub device notation
-
-=cut
 
 sub get_partition_number
 {
         my ($self, $device_file) = @_;
-	my ($partition_number) = $device_file =~ m/(\d+)/;
-	$partition_number--;
-	return $partition_number;
+        my ($partition_number) = $device_file =~ m/(\d+)/;
+        $partition_number--;
+        return $partition_number;
 }
 
-=head2 get_grub_device
-
-Get the disc part of grub notation of a given device file eg. /dev/hda1.
-
-@param string - device file name
-
-@return success - (0, grub device notation)
-@return eror    - (1, error string)
-
-=cut
 
 sub get_grub_device
 {
@@ -61,36 +37,34 @@ sub get_grub_device
                                         "--root-directory=$basedir","--no-floppy","$device_file");
         my ($grub_device) = $device_file =~ m/[hs]d([a-z])/;
         $grub_device      =~ tr/[a-j]/[0-9]/;
-	if ($grub_device eq "") {
+        if ($grub_device eq "") {
                 $self->log->warn( "Grub device not found, took '0'");
                 $grub_device = 0;
-  	}
-	return (0, $grub_device);
+        }
+        return (0, $grub_device);
 }
 
 
 
-=head2 configure_fstab
-
-Write fstab on installed system based upon the installed images and
-partitions.
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub configure_fstab
 {
         my ($self) = @_;
-	# Creates fstab-entry for the final partition
+        # Creates fstab-entry for the final partition
 
         $self->log->debug("Configuring fstab to contain installed images");
         open (my $FSTAB, ">", $self->cfg->{paths}{base_dir}."/etc/fstab") or return "Can't open fstab for appending: $!";
 
         # write defaults for fstab
         print $FSTAB "proc\t/proc\tproc\tdefaults\t0 0\n","sysfs\t/sys\tsysfs\tauto\t0 0\n";
-	print $FSTAB "/data/tapper tapper:/data/tapper nfs noauto,vers=3 0 0\n";
+        print $FSTAB "tapper:/data/tapper /data/tapper nfs vers=3 0 0\n";
+
+        # put swap in fstab
+        foreach my $line (grep {$_ =~ m/swap/i} qx(fdisk -l)) {
+                my ($file_name) = split / +/, $line;
+                print $FSTAB "$file_name\tnone\tswap\tsw\t0\t0\n";
+        }
+
 
         foreach my $image (@{$self->images}) {
                 print $FSTAB $image->{partition},"\t",$image->{mount},"\text3\tdefaults\t1 1\n";
@@ -101,16 +75,6 @@ sub configure_fstab
 }
 
 
-=head2 generate_user_grub_conf
-
-Generate grub config file menu.lst based upon user provided precondition.
-
-@param string - name of the root partition
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub generate_user_grub_conf
 {
@@ -118,27 +82,21 @@ sub generate_user_grub_conf
         my $mount_point=$self->cfg->{paths}{base_dir};
         my $conf_string=$self->cfg->{grub};
 
-	my $partition_number = $self->get_partition_number($device_file);
-	my ($error, $grub_device) = $self->get_grub_device( $device_file);
+        my $partition_number = $self->get_partition_number($device_file);
+        my ($error, $grub_device) = $self->get_grub_device( $device_file);
         return $grub_device if $error;
 
+        my $initrd_options = '';
+        $initrd_options = "initrd /boot/initrd" if -e $self->cfg->{paths}{base_dir}."/boot/initrd";
+
         $conf_string =~ s/\$root/$device_file/g;
         $conf_string =~ s/\$grubroot/(hd$grub_device,$partition_number)/g;
+        $conf_string =~ s/\$initrd_options/$initrd_options/g;
 
         return $self->write_menu_lst($conf_string, "truncate");
 }
 
 
-=head2 generate_grub_menu_lst
-
-Create a grub config file (menu.lst) based on the options in the configuration
-hash. The function is mainly a wrapper for create_menu_lst_entry and
-create_new_menu_lst.
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub generate_grub_menu_lst
 {
@@ -147,24 +105,11 @@ sub generate_grub_menu_lst
 
         my $partition = $self->images->[0]->{partition};
 
-        if ($self->cfg->{grub}) {
-                return $retval if $retval = $self->generate_user_grub_conf($partition);
-        } else {
-                return $retval if $retval = $self->create_new_menu_lst();
-                return $retval if $retval = $self->create_menu_lst_entry($partition);
-        }
-	return 0;
+        return $retval if $retval = $self->generate_user_grub_conf($partition);
+        return 0;
 }
 
 
-=head2 prepare_boot
-
-Make installed system ready for boot from hard disk.
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub prepare_boot
 {
@@ -172,25 +117,12 @@ sub prepare_boot
         my $retval = 0;
         return $retval if $retval = $self->configure_fstab();
         return $retval if $retval = $self->generate_grub_menu_lst( );
-	return $retval if $retval = $self->generate_pxe_grub();
-# 	return $retval if $retval = $self->copy_menu_lst();
+        return $retval if $retval = $self->generate_pxe_grub();
+        # return $retval if $retval = $self->copy_menu_lst();
         return 0;
 }
 
 
-=head2 get_device
-
-Return device name (i.e. /dev/$device) for a given device-id, partition label
-or $device name (with or without preceding /dev/).
-Doesn't work with dev-mapper.
-
-@param string - device or reference to array with device ids
-@param string - base dir prepended to all paths (testing purpose)
-
-@returnlist success - ( 0, device name string)
-@returnlist error   - ( 1, error string)
-
-=cut
 
 sub get_device
 {
@@ -230,17 +162,6 @@ sub get_device
 
 
 
-=head2 get_partition_label
-
-Get the label of a partition to be able to set it again at mkfs.
-
-@param string - device file
-
-@returnlist success - (    0, partition label string)
-@returnlist error   - ( != 0, error string)
-
-
-=cut
 
 sub get_partition_label
 {
@@ -250,14 +171,6 @@ sub get_partition_label
 
 
 
-=head2 generate_pxe_grub
-
-Generate a simple PXE grub config that forwards to local grub.
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub generate_pxe_grub
 {
@@ -265,8 +178,8 @@ sub generate_pxe_grub
 
         my $partition = $self->cfg->{preconditions}->[0]->{partition};
         my $hostname = $self->gethostname();
-	my $partition_number = $self->get_partition_number( $partition );
-	my ($error, $grub_device) = $self->get_grub_device( $partition );
+        my $partition_number = $self->get_partition_number( $partition );
+        my ($error, $grub_device) = $self->get_grub_device( $partition );
         return $grub_device if $error;
 
 
@@ -285,100 +198,25 @@ sub generate_pxe_grub
 
 
 
-=head2 copy_menu_lst
-
-Copy menu.lst to NFS. We need the grub config file menu.lst on NFS because
-thats where PXE grub expects it. Still we create the file on the local hard
-drive because it's faster and allows users to boot with this config without
-using PXE grub.
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub copy_menu_lst
 {
         my ($self) = @_;
+
         my $hostname      = $self->gethostname();
         my $menu_lst_file = $self->cfg->{paths}{base_dir}."/boot/grub/menu.lst";
-
-        my $tapper_conf  = $self->cfg->{paths}{grubpath};
+        my $tapper_conf   = $self->cfg->{paths}{grubpath};
 
         return $self->log_and_exec("cp $menu_lst_file $tapper_conf/$hostname.lst");
 }
 
 
-=head2 create_menu_lst_entry
-
-Create and entry for the installed kernel in menu.lst. The kernel must be
-named /boot/vmlinuz.
-
-@param string - name of the root partition
-
-@return success - 0
-@return error   - error string
-
-=cut
-
-sub create_menu_lst_entry
-{
-        my ($self, $device_file) = @_;
-	my $partition_number     = $self->get_partition_number($device_file);
-	my ($error,$grub_device) = $self->get_grub_device( $device_file);
-        return $grub_device if $error;
-        my $id                   = $self->cfg->{testrun};
-        $id ||="unknown";
-        my $entry                = "title Test run $id\n".
-          "root (hd$grub_device,$partition_number)\n".
-            "kernel /boot/vmlinuz root=$device_file earlyprintk=serial,ttyS0,115200 ".
-              "console=ttyS0,115200 ip=dhcp noapic tapper_host=".$self->cfg->{server}."\n";
-        $entry .= "initrd /boot/initrd\n\n" if -e $self->cfg->{paths}{base_dir}."/boot/initrd";
-
-
-        return $self->write_menu_lst($entry,0);
-}
-
-
-=head2 create_new_menu_lst
-
-Create a new menu.lst with default header information. Existing grub configs
-are silently overwritten.
-
-@return success - 0
-@return error   - error string
-
-=cut
-
-sub create_new_menu_lst
-{
-        my ($self) = @_;
-        my $base = "serial --unit=0 --speed=115200\n".
-          "terminal serial\n".
-            "timeout 3\n".
-              "default 0\n\n\n";
-        return $self->write_menu_lst($base,"truncate");
-}
-
-
-=head2 write_menu_lst
-
-Write content to grub file. This encapsulates writing to improve readability
-and testability.
-
-@param string - what to write
-@param bool   - true = truncate ('>'), false = append ('>>') (append is default)
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub write_menu_lst
 {
         my ($self, $content, $truncate) = @_;
-	$self->makedir($self->cfg->{paths}{base_dir}."/boot/grub/");
-	my $menu_lst_file = $self->cfg->{paths}{base_dir}."/boot/grub/menu.lst";
+        $self->makedir($self->cfg->{paths}{base_dir}."/boot/grub/");
+        my $menu_lst_file = $self->cfg->{paths}{base_dir}."/boot/grub/menu.lst";
         my $mode = '>>';
         if ($truncate) {
                 $mode = '>';
@@ -391,18 +229,6 @@ sub write_menu_lst
 }
 ;
 
-=head2 install
-
-Install a given image. This function is a wrapper for image
-installer functions so the caller doesn't need to care for preparations.
-
-@param hash reference - containing image name (image), mount point (mount) and
-                        partition name (partition)
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub install
 {
@@ -423,7 +249,7 @@ sub install
         # mount points in image precondition are relative to test system root
         # installation needs it relative to current root
         my $mount_point = $self->cfg->{paths}{base_dir}.$image->{mount};
-	$error = $self->makedir($mount_point);
+        $error = $self->makedir($mount_point);
         return $error if $error;
 
         if ($image->{image}) {
@@ -443,24 +269,11 @@ sub install
 }
 
 
-=head2 install_image
-
-Install an image on a given device and mount it to a given mount point. Make
-sure to set partition label reasonably.
-
-@param string - image file name
-@param string - device file name
-@param string - mount point relative to future test system
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub install_image
 {
         my ($self, $image_file, $device_file, $mount_point) = @_;
- 	my ($error, $partition_size)=$self->log_and_exec("/sbin/blockdev --getsize64 $device_file");
+        my ($error, $partition_size)=$self->log_and_exec("/sbin/blockdev --getsize64 $device_file");
         if ($error) {
                 $self->log->warn("Can't get size of partition $device_file: $partition_size. Won't check if images fits.");
                 $partition_size = 0;
@@ -469,44 +282,30 @@ sub install_image
         my ($partition_label, $image_type);
         ($error, $image_type)=$self->get_file_type($image_file);
 
-	($error, $partition_label) = $self->get_partition_label($device_file);
+        ($error, $partition_label) = $self->get_partition_label($device_file);
         if ($error) {
                 $self->log->info("Can't get partition label of $device_file: $partition_label");
                 $partition_label='';
         }
-	$partition_label ||= "testing";
+        $partition_label ||= "testing";
 
-	if ($image_type eq "iso") {
+        if ($image_type eq "iso") {
                 # ISO images are preformatted and thus bring their own
                 # partition label
-		return $self->install_image_iso($image_file, $partition_size, $device_file, $mount_point);
+                return $self->install_image_iso($image_file, $partition_size, $device_file, $mount_point);
         } elsif ($image_type eq "tar") {
-		return $self->install_image_tar($image_file, $partition_size, $device_file, $mount_point, $partition_label);
+                return $self->install_image_tar($image_file, $partition_size, $device_file, $mount_point, $partition_label);
         } elsif ($image_type eq "gzip"){
-		return $self->install_image_gz($image_file, $partition_size, $device_file, $mount_point, $partition_label);
+                return $self->install_image_gz($image_file, $partition_size, $device_file, $mount_point, $partition_label);
         } elsif ($image_type eq "bz2") {
-		return $self->install_image_bz2($image_file, $partition_size, $device_file, $mount_point, $partition_label);
+                return $self->install_image_bz2($image_file, $partition_size, $device_file, $mount_point, $partition_label);
         } else {
                 return("Imagetype could not be detected");
-	}
+        }
         return 0;
 }
 
 
-=head2 install_image_iso
-
-Install an image of type iso.
-
-@param string - image file name
-@param int    - size of the target partition
-@param string - device name of the target partition
-@param string - directory to mount the installed image to
-
-@return success - 0
-@return error   - error string
-
-
-=cut
 
 sub install_image_iso
 {
@@ -524,21 +323,6 @@ sub install_image_iso
 }
 
 
-=head2 install_image_tar
-
-
-Install an image of type tar.
-
-@param string - image file name
-@param int    - size of the target partition
-@param string - device name of the target partition
-@param string - directory to mount the installed image to
-@param string - partition label
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub install_image_tar
 {
@@ -556,20 +340,6 @@ sub install_image_tar
         return 0;
 }
 
-=head2 install_image_gz
-
-Install an image of type tar.gz.
-
-@param string - image file name
-@param int    - size of the target partition
-@param string - device name of the target partition
-@param string - directory to mount the installed image to
-@param string - partition labe
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub install_image_gz
 {
@@ -587,20 +357,6 @@ sub install_image_gz
         return 0;
 }
 
-=head2 install_image_bz2
-
-Install an image of type tar.bz2.
-
-@param string - image file name
-@param int    - size of the target partition
-@param string - device name of the target partition
-@param string - directory to mount the installed image to
-@param string - partition labe
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub install_image_bz2
 {
@@ -619,40 +375,19 @@ sub install_image_bz2
 }
 
 
-=head2 copy_image
-
-Install an image to a given partition and mount it to a given mount point.
-
-@param string - device name
-@param string - image file
-@param string - mount point
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub copy_image
 {
         my ($self, $device_file, $image_file, $mount_point) = @_;
-        $image_file = $self->cfg->{paths}{image_dir}.$image_file unless $image_file =~m(^/); 
+        $image_file = $self->cfg->{paths}{image_dir}.$image_file unless $image_file =~m(^/);
 
-	# Image exists?
+        # Image exists?
         if (not -e $image_file) {
                 return("Image $image_file could not be found");
         }
-	return $self->install_image($image_file, $device_file, $mount_point);
+        return $self->install_image($image_file, $device_file, $mount_point);
 }
 
-=head2 unmount
-
-Umounts all images that were mounted during installation in reverse
-order.
-
-@return success - 0
-@return error   - error string
-
-=cut
 
 sub unmount
 {
@@ -668,26 +403,227 @@ sub unmount
 
 1;
 
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::Installer::Precondition::Image
+
+=head1 SYNOPSIS
+
+ use Tapper::Installer::Precondition::Image;
+
+=head1 NAME
+
+Tapper::Installer::Precondition::Package - Install a package to a given location
+
+=head1 FUNCTIONS
+
+=head2 get_partition_number
+
+Get the partition part of grub notation of a given device file eg. /dev/hda1.
+
+@param string - partition number
+
+@return int - grub device notation
+
+=head2 get_grub_device
+
+Get the disc part of grub notation of a given device file eg. /dev/hda1.
+
+@param string - device file name
+
+@return success - (0, grub device notation)
+@return eror    - (1, error string)
+
+=head2 configure_fstab
+
+Write fstab on installed system based upon the installed images and
+partitions.
+
+@return success - 0
+@return error   - error string
+
+=head2 generate_user_grub_conf
+
+Generate grub config file menu.lst based upon user provided precondition.
+
+@param string - name of the root partition
+
+@return success - 0
+@return error   - error string
+
+=head2 generate_grub_menu_lst
+
+Create a grub config file (menu.lst) based on the options in the configuration
+hash.
+
+@return success - 0
+@return error   - error string
+
+=head2 prepare_boot
+
+Make installed system ready for boot from hard disk.
+
+@return success - 0
+@return error   - error string
+
+=head2 get_device
+
+Return device name (i.e. /dev/$device) for a given device-id, partition label
+or $device name (with or without preceding /dev/).
+Doesn't work with dev-mapper.
+
+@param string - device or reference to array with device ids
+@param string - base dir prepended to all paths (testing purpose)
+
+@returnlist success - ( 0, device name string)
+@returnlist error   - ( 1, error string)
+
+=head2 get_partition_label
+
+Get the label of a partition to be able to set it again at mkfs.
+
+@param string - device file
+
+@returnlist success - (    0, partition label string)
+@returnlist error   - ( != 0, error string)
+
+=head2 generate_pxe_grub
+
+Generate a simple PXE grub config that forwards to local grub.
+
+@return success - 0
+@return error   - error string
+
+=head2 copy_menu_lst
+
+Copy menu.lst to NFS. We need the grub config file menu.lst on NFS because
+thats where PXE grub expects it. Still we create the file on the local hard
+drive because it's faster and allows users to boot with this config without
+using PXE grub.
+
+@return success - 0
+@return error   - error string
+
+=head2 write_menu_lst
+
+Write content to grub file. This encapsulates writing to improve readability
+and testability.
+
+@param string - what to write
+@param bool   - true = truncate ('>'), false = append ('>>') (append is default)
+
+@return success - 0
+@return error   - error string
+
+=head2 install
+
+Install a given image. This function is a wrapper for image
+installer functions so the caller doesn't need to care for preparations.
+
+@param hash reference - containing image name (image), mount point (mount) and
+                        partition name (partition)
+
+@return success - 0
+@return error   - error string
+
+=head2 install_image
+
+Install an image on a given device and mount it to a given mount point. Make
+sure to set partition label reasonably.
+
+@param string - image file name
+@param string - device file name
+@param string - mount point relative to future test system
+
+@return success - 0
+@return error   - error string
+
+=head2 install_image_iso
+
+Install an image of type iso.
+
+@param string - image file name
+@param int    - size of the target partition
+@param string - device name of the target partition
+@param string - directory to mount the installed image to
+
+@return success - 0
+@return error   - error string
+
+=head2 install_image_tar
+
+Install an image of type tar.
+
+@param string - image file name
+@param int    - size of the target partition
+@param string - device name of the target partition
+@param string - directory to mount the installed image to
+@param string - partition label
+
+@return success - 0
+@return error   - error string
+
+=head2 install_image_gz
+
+Install an image of type tar.gz.
+
+@param string - image file name
+@param int    - size of the target partition
+@param string - device name of the target partition
+@param string - directory to mount the installed image to
+@param string - partition labe
+
+@return success - 0
+@return error   - error string
+
+=head2 install_image_bz2
+
+Install an image of type tar.bz2.
+
+@param string - image file name
+@param int    - size of the target partition
+@param string - device name of the target partition
+@param string - directory to mount the installed image to
+@param string - partition labe
+
+@return success - 0
+@return error   - error string
+
+=head2 copy_image
+
+Install an image to a given partition and mount it to a given mount point.
+
+@param string - device name
+@param string - image file
+@param string - mount point
+
+@return success - 0
+@return error   - error string
+
+=head2 unmount
+
+Umounts all images that were mounted during installation in reverse
+order.
+
+@return success - 0
+@return error   - error string
+
 =head1 AUTHOR
 
-AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
+AMD OSRC Tapper Team <tapper@amd64.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-None.
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
 
-=head1 SUPPORT
+This is free software, licensed under:
 
-You can find documentation for this module with the perldoc command.
+  The (two-clause) FreeBSD License
 
- perldoc Tapper
+=cut
 
-
-=head1 ACKNOWLEDGEMENTS
-
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
-
-This program is released under the following license: freebsd
